diff --git a/app/views/admin/info.rhtml b/app/views/admin/info.rhtml
index eef1a67..02ae2bf 100644
--- a/app/views/admin/info.rhtml
+++ b/app/views/admin/info.rhtml
@@ -1,6 +1,6 @@
 <h2><%=l(:label_information_plural)%></h2>
 
-<p><strong><%= Redmine::Info.versioned_name %></strong> (<%= @db_adapter_name %>)</p>
+<p><strong><%= Redmine::Info.versioned_name %></strong></p>
 
 <table class="list">
 <% @checklist.each do |label, result| %>
@@ -10,5 +10,9 @@
 	</tr>
 <% end %>
 </table>
+<br />
+<div class="box">
+<pre><%= ChiliProject::Info.environment %></pre>
+</div>
 
 <% html_title(l(:label_information_plural)) -%>
diff --git a/lib/chili_project/info.rb b/lib/chili_project/info.rb
index ef15cce..654d333 100644
--- a/lib/chili_project/info.rb
+++ b/lib/chili_project/info.rb
@@ -26,6 +26,34 @@ module ChiliProject
       def issue(issue_id)
         url + 'issues/' + issue_id.to_s
       end
+
+      def environment
+        s = "Environment:\n"
+        s << [
+          ["ChiliProject version", ChiliProject::VERSION],
+          ["Ruby version", "#{RUBY_VERSION}-p#{RUBY_PATCHLEVEL} (#{RUBY_RELEASE_DATE}) [#{RUBY_PLATFORM}]"],
+          ["Rails version", Rails::VERSION::STRING],
+          ["Environment", Rails.env],
+          ["Database adapter", ChiliProject::Database.adapter_name]
+        ].map {|info| "  %-30s %s" % info}.join("\n") + "\n"
+
+        s << "SCM:\n"
+        Redmine::Scm::Base.all.each do |scm|
+          scm_class = "Repository::#{scm}".constantize
+          if scm_class.scm_available
+            s << "  %-30s %s\n" % [scm, scm_class.scm_version_string]
+          end
+        end
+
+        s << "ChiliProject plugins:\n"
+        plugins = Redmine::Plugin.all
+        if plugins.any?
+          s << plugins.map {|plugin| "  %-30s %s" % [plugin.id.to_s, plugin.version.to_s]}.join("\n")
+        else
+          s << "  no plugin installed"
+        end
+      end
+
     end
   end
 end
\ No newline at end of file
diff --git a/test/unit/lib/chili_project/info_test.rb b/test/unit/lib/chili_project/info_test.rb
new file mode 100644
index 0000000..c4b1f47
--- /dev/null
+++ b/test/unit/lib/chili_project/info_test.rb
@@ -0,0 +1,27 @@
+#-- encoding: UTF-8
+#-- copyright
+# ChiliProject is a project management system.
+#
+# Copyright (C) 2010-2013 the ChiliProject Team
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# See doc/COPYRIGHT.rdoc for more details.
+#++
+require File.expand_path('../../../../test_helper', __FILE__)
+
+class ChiliProject::InfoTest < ActiveSupport::TestCase
+  def test_environment
+    env = ChiliProject::Info.environment
+
+    assert_kind_of String, env
+    assert_match 'Environment:', env
+    assert_match 'ChiliProject version', env
+    assert_match 'SCM:', env
+    assert_match 'ChiliProject plugins:', env
+
+  end
+end
\ No newline at end of file
